<?php
defined('ABSPATH') or die("No direct script access!");


function qc_clr_top_comments_widgets() {
	register_widget( 'qc_clr_top_commenters' );
}


class qc_clr_top_commenters extends WP_Widget {

	/**
	 * Widget setup.
	 */
	public function __construct(){
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'example', 'description' => esc_html('A list of top commenters on your site', 'qc-clr') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 300, 'height' => 350, 'id_base' => 'qc-clr-top-commenters' );

		/* Create the widget. */
		parent::__construct( 'qc-clr-top-commenters', esc_html('QC CLR Top Commenters', 'qc-clr'), $widget_ops, $control_ops );
	}

	public function qc_clr_top_commenters(){
		self::__construct();
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		$clr_options = get_option( 'comment_link_remove_option_name' );

		$comment_sidebar_widget_show_top_comment_post_page_only = isset($clr_options['comment_sidebar_widget_show_top_comment_post_page_only']) ? $clr_options['comment_sidebar_widget_show_top_comment_post_page_only'] : '';

		if ($comment_sidebar_widget_show_top_comment_post_page_only == 1 && get_post_type() === 'page') {
		    return;
		}

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$name = $instance['excludeCommenters'];
		$identifier = $instance['identifier'];
		$limit = $instance['limit'];
		$showCommentsLabel = $instance['show_comments_label'];

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

		/* Process variables */
		if ($instance['excludeCommenters'] != ""){
			$excludedCommenters = trim($instance['excludeCommenters']);
			$excludedCommenters = explode(",", $excludedCommenters);
		}
		else{
			$excludedCommenters = array('');
		}
		
		$excludedEmailQuery = '';
		for ($l=0; $l<count($excludedCommenters); $l++){
			$excludedEmailQuery .= " AND comment_author_email != '".trim($excludedCommenters[$l])."' \r";
		}
		
		$excludedNameQuery = '';
		for ($m=0; $m<count($excludedCommenters); $m++){
			$excludedNameQuery .= " AND comment_author != '".trim($excludedCommenters[$m])."' \r";
		}
		
		if ($identifier == 'name'){
			$groupByQuery = 'GROUP BY comment_author';
		}
		else{
			$groupByQuery = 'GROUP BY comment_author_email';
		}
		
		settype($limit, 'int');
		
		if (($limit > 0) && (is_int($limit) == true)){
			$limitQuery = 'LIMIT '.$limit;
		}
		else{
			$limitQuery = '';
		}
		//}
		
		/* MySQL query */
		global $wpdb;
		global $post;

		if(isset($post->ID) && !empty($post->ID) && (get_post_type() === 'post') ){
			$commenters = $wpdb->get_results("
				SELECT count(*) as qty, comment_author_email, comment_author
				FROM $wpdb->comments
				WHERE comment_type != 'pingback'
				$excludedEmailQuery
				$excludedNameQuery
				AND comment_approved = '1'
				AND comment_post_ID = $post->ID
				$groupByQuery
				ORDER BY qty DESC
				$limitQuery
			");

		}else{

			$commenters = $wpdb->get_results("
				SELECT count(*) as qty, comment_author_email, comment_author
				FROM $wpdb->comments
				WHERE comment_type != 'pingback'
				$excludedEmailQuery
				$excludedNameQuery
				AND comment_approved = '1'
				$groupByQuery
				ORDER BY qty DESC
				$limitQuery
			");
		}
		
		/* Display list */
		?>
		<!-- opening ul tag to contain the list -->
		<ul>
		<?php
			if(is_array($commenters)) {
				
				//only shows "comments" if "show comments label" is set to true
				if($showCommentsLabel == true){
					foreach ($commenters as $k) {
						echo ('<li> <a href="'.get_author_posts_url( get_the_author_meta( 'ID' ) ).'" style="font-weight: bold">'.$k->comment_author.'</a> : '.$k->qty.' '._n('comment', 'comments', $k->qty, 'qc_clr_top_commenters').'</li>');
					} //end for loop
				} // end if showCommentsLabel == on
				
				//if "show comments label" is set to false, does not show "comments"
				else{
					foreach ($commenters as $w) {
						echo ('<li>'.$w->comment_author.': '.$w->qty);
					} //end for loop
				}
				
				
			} //end if is array
		?>
		<!-- closing ul tag to contain the list -->
		</ul>
		<?php
		
		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['excludeCommenters'] = strip_tags( $new_instance['excludeCommenters'] );
		$instance['limit'] = strip_tags( $new_instance['limit'] );

		/* No need to strip tags for these inputs */
		$instance['identifier'] = $new_instance['identifier'];
		$instance['show_comments_label'] = isset($new_instance['show_comments_label']);

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => esc_html('Top Commenters', 'qc-clr'), 'excludeCommenters' => esc_attr('Bert, Ernie@sesamestreet.com', 'qc-clr'), 'identifier' => 'email', 'limit' => 5, 'show_comments_label' => true );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'qc-clr'); ?></label>
			</br>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr($instance['title']); ?>" size="40"/>
		</p>

		<!-- Define Commenters Select Box -->
		<p>
			<label for="<?php echo $this->get_field_id( 'identifier' ); ?>"><?php _e('Commenters Gorup by:', 'qc-clr'); ?></label>
			</br> 
			<select id="<?php echo $this->get_field_id( 'identifier' ); ?>" name="<?php echo $this->get_field_name( 'identifier' ); ?>">
				<option <?php if ( 'email' == $instance['identifier'] ) echo 'selected="selected"'; ?>><?php _e('Email', 'qc-clr'); ?></option>
				<option <?php if ( 'name' == $instance['identifier'] ) echo 'selected="selected"'; ?>><?php _e('Name', 'qc-clr'); ?></option>
			</select>
		</p>
		
		<!-- Your Name: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'excludeCommenters' ); ?>"><?php _e('Commenters to Exclude: (separated by comma)', 'qc-clr'); ?></label>
			</br>
			<input id="<?php echo $this->get_field_id( 'excludeCommenters' ); ?>" name="<?php echo $this->get_field_name( 'excludeCommenters' ); ?>" value="<?php echo $instance['excludeCommenters']; ?>" size="40"/>
		</p>
		
		<!-- Limit -->
		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>"><?php _e('# of Commenters to List: (leave blank to list all)', 'qc-clr'); ?></label>
			</br>
			<input id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" value="<?php echo $instance['limit']; ?>" style="width:2em;" />
		</p>
		
		<!-- Show "comments label" Checkbox -->
		<p>
			<input class="checkbox" type="checkbox" <?php checked(isset( $instance['show_comments_label']) ? $instance['show_comments_label'] : 0 ); ?> id="<?php echo $this->get_field_id( 'show_comments_label' ); ?>" name="<?php echo $this->get_field_name( 'show_comments_label' ); ?>" /> 
			<label for="<?php echo $this->get_field_id( 'show_comments_label' ); ?>"><?php _e('Show "comments" Label?', 'qc-clr'); ?></label>
		</p>

	<?php
	}
}
?>